antimeridian
============

A Python module for fixing geometries that cross the `antimeridian <https://en.wikipedia.org/wiki/180th_meridian>`_.
See `the project README <https://github.com/gadomski/antimeridian/tree/main/README.md>`_ for more information about the antimeridian problem and the algorithm used in this project.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   api


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
